<!-- LANG:zh_TW -->
## 說明
<!--
請包含此次變更的摘要以及修正的問題。
請提供相關的動機和背景資訊，例如：計畫需求、資安風險。
請列出此變更新增依賴的任何套件或工具。

如果此次拉取請求關聯特定議題，並希望於合併後自動關閉追蹤，請於本段落參考以下語法填寫：

Closes #議題編號

-->

## 變更類型
<!-- 請勾選此次變更涉及的項目。 -->

- [ ] 🐛 問題修復（不影響現有需求功能，例如：補丁、故障排除）
- [ ] ✨ 新增功能（添加的新功能不會對原結構造成破壞性的變動）
- [ ] 💥 重大變更（會導致現有功能無法運作或行為改變的大更新）
- [ ] 📝 文件更新（包含此次修改需補充說明、設定檔或資源異動）

## 驗證測試
<!--
請包含您為此次變更執行的驗證與測試內容。
請提供可重現的指令與操作步驟說明。
請列出所有相關的測試環境配置及詳細資訊。

範例： 

- [ ] 單元測試
- [ ] 整合測試

**測試配置**:

- 防火牆版本:
- 硬體需求:
- 工具集:
- 軟體開發套件:

---

如果不適用（例如：僅包含README、LICENSE等文件更新）請填寫：

_`N/A`_

-->

## 自我檢核
<!-- 請檢查並確認所有自我檢測任務均已完成。 -->

- [ ] 我的程式碼符合本專案的風格指引
- [ ] 我已完成對程式碼的自我審查
- [ ] 我在程式碼中添加了註解，特別是邏輯較為複雜的部分
- [ ] 我已同步更新相關文件
- [ ] 我的修改未產生任何新的警告
- [ ] 我已完成測試，確認修正有效且功能正常運作
- [ ] 新增和現有的單元測試在本機執行時均通過
<!--
以下檢核項不適用於本專案，僅供參考並保留作為日後擴充。

- [ ] 所有相依的修改已合併並發布至下游模組

-->
